@@ -30,6 +30,8 @@ class Operation:
         env = os.environ.copy()
         env.update(kwargs.get("env", {}))
         kwargs["env"] = env
+        if not secret and dandori.log.get_levelname() == "DEBUG":
+            kwargs["echo"] = True
         try:
             if not secret:
                 L.verbose3("Execute: %s", args)
@@ -67,11 +69,12 @@ class Operation:
 
     def _prepare_venv(self, python_path, name):
         venv_dir = dandori.env.tempdir() / name
+        env = {
+            "VIRTUAL_ENV": str(venv_dir),
+            "PATH": f"{venv_dir}/bin:{os.environ['PATH']}",
+        }
         if not venv_dir.exists():
             self.run([python_path, "-m", "venv", "--clear", "--symlinks", str(venv_dir)])
         if not venv_dir.exists():
             raise dandori.exception.Failure(f"Virtualenv directory does not exist: {venv_dir}")
-        return {
-            "VIRTUAL_ENV": str(venv_dir),
-            "PATH": f"{venv_dir}/bin:{os.environ['PATH']}",
-        }
+        return env
